@@ -1,9 +1,8 @@
-;;; test-ellama.el --- Ellama tests -*- lexical-binding: t -*-
+;;; test-ellama.el --- Ellama tests -*- lexical-binding: t; package-lint-main-file: "../ellama.el"; -*-
 
-;; Copyright (C) 2023  Free Software Foundation, Inc.
+;; Copyright (C) 2023-2025  Free Software Foundation, Inc.
 
 ;; Author: Sergey Kostyaev <sskostyaev@gmail.com>
-;; Package-Requires: ((emacs "28.1") (llm "0.6.0") (spinner "1.7.4"))
 
 ;; This file is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -89,7 +88,7 @@
 (ert-deftest test-ellama-context-element-format-webpage-quote-disabled-markdown ()
   (let ((element (ellama-context-element-webpage-quote :name "test name" :url "https://example.com/" :content "1\n\n2"))
 	(ellama-show-quotes nil))
-    (should (equal "[test name](https://example.com/)" (ellama-context-element-format element 'markdown-mode)))))
+    (should (string-match "\\[test name\\](https://example.com/):\n```emacs-lisp\n(display-buffer \"\\*ellama-quote-.+\\*\")\n```\n" (ellama-context-element-format element 'markdown-mode)))))
 
 (ert-deftest test-ellama-context-element-format-webpage-quote-enabled-markdown ()
   (let ((element (ellama-context-element-webpage-quote :name "test name" :url "https://example.com/" :content "1\n\n2"))
@@ -105,7 +104,7 @@
 (ert-deftest test-ellama-context-element-format-webpage-quote-disabled-org-mode ()
   (let ((element (ellama-context-element-webpage-quote :name "test name" :url "https://example.com/" :content "1\n\n2"))
 	(ellama-show-quotes nil))
-    (should (equal "[[https://example.com/][test name]]" (ellama-context-element-format element 'org-mode)))))
+    (should (string-match "\\[\\[https://example.com/\\]\\[test name\\]\\] \\[\\[elisp:(display-buffer \"\\*ellama-quote-.+\\*\")\\]\\[show\\]\\]" (ellama-context-element-format element 'org-mode)))))
 
 (ert-deftest test-ellama-context-element-format-webpage-quote-enabled-org-mode ()
   (let ((element (ellama-context-element-webpage-quote :name "test name" :url "https://example.com/" :content "1\n\n* 2"))
@@ -122,7 +121,7 @@
 (ert-deftest test-ellama-context-element-format-info-node-quote-disabled-markdown ()
   (let ((element (ellama-context-element-info-node-quote :name "(emacs)Top" :content "1\n\n2"))
 	(ellama-show-quotes nil))
-    (should (equal "```emacs-lisp\n(info \"(emacs)Top\")\n```\n" (ellama-context-element-format element 'markdown-mode)))))
+    (should (string-match "```emacs-lisp\n(info \"(emacs)Top\")\n```\nshow:\n```emacs-lisp\n(display-buffer \"\\*ellama-quote-.+\\*\")\n```\n" (ellama-context-element-format element 'markdown-mode)))))
 
 (ert-deftest test-ellama-context-element-format-info-node-quote-enabled-markdown ()
   (let ((element (ellama-context-element-info-node-quote :name "(emacs)Top" :content "1\n\n2"))
@@ -133,7 +132,7 @@
 (ert-deftest test-ellama-context-element-format-info-node-quote-disabled-org-mode ()
   (let ((element (ellama-context-element-info-node-quote :name "(emacs)Top" :content "1\n\n2"))
 	(ellama-show-quotes nil))
-    (should (equal "[[(emacs)Top][(emacs)Top]]" (ellama-context-element-format element 'org-mode)))))
+    (should (string-match "\\[\\[(emacs)Top\\]\\[(emacs)Top\\]\\] \\[\\[elisp:(display-buffer \"\\*ellama-quote-.+\\*\")\\]\\[show\\]\\]" (ellama-context-element-format element 'org-mode)))))
 
 (ert-deftest test-ellama-context-element-format-info-node-quote-enabled-org-mode ()
   (let ((element (ellama-context-element-info-node-quote :name "(emacs)Top" :content "1\n\n* 2"))
@@ -144,7 +143,7 @@
 (ert-deftest test-ellama-context-element-format-file-quote-disabled-markdown ()
   (let ((element (ellama-context-element-file-quote :path "/tmp/test.txt" :content "1\n\n2"))
 	(ellama-show-quotes nil))
-    (should (equal "[/tmp/test.txt](/tmp/test.txt)" (ellama-context-element-format element 'markdown-mode)))))
+    (should (string-match "\\[/tmp/test.txt\\](/tmp/test.txt):\n```emacs-lisp\n(display-buffer \"\\*ellama-quote-.+\\*\")" (ellama-context-element-format element 'markdown-mode)))))
 
 (ert-deftest test-ellama-context-element-format-file-quote-enabled-markdown ()
   (let ((element (ellama-context-element-file-quote :path "/tmp/test.txt" :content "1\n\n2"))
@@ -160,7 +159,7 @@
 (ert-deftest test-ellama-context-element-format-file-quote-disabled-org-mode ()
   (let ((element (ellama-context-element-file-quote :path "/tmp/test.txt" :content "1\n\n2"))
 	(ellama-show-quotes nil))
-    (should (equal "[[/tmp/test.txt][/tmp/test.txt]]" (ellama-context-element-format element 'org-mode)))))
+    (should (string-match "\\[\\[/tmp/test.txt\\]\\[/tmp/test.txt\\]\\] \\[\\[elisp:(display-buffer \"\\*ellama-quote-.+\\*\")\\]\\[show\\]\\]" (ellama-context-element-format element 'org-mode)))))
 
 (ert-deftest test-ellama-context-element-format-file-quote-enabled-org-mode ()
   (let ((element (ellama-context-element-file-quote :path "/tmp/test.txt" :content "1\n\n* 2"))
@@ -304,6 +303,96 @@ third block
 #+END_SRC
 That's it."))))
 
+(ert-deftest test-ellama-md-to-org-code-inline-latex ()
+  (let ((result (ellama--translate-markdown-to-org-filter "_some italic_
+$$P_\\theta(Y_T, ..., Y_2|Y_1, x_1, ..., x_T)$$
+_more italic_
+$P_\\theta$
+_more italic_")))
+    (should (string-equal result "/some italic/
+$$P_\\theta(Y_T, ..., Y_2|Y_1, x_1, ..., x_T)$$
+/more italic/
+$P_\\theta$
+/more italic/"))))
+
+
+(ert-deftest test-ellama-md-to-org-code-inline-latex-with-code ()
+  (let ((result (ellama--translate-markdown-to-org-filter "_some italic_
+$$P_\\theta(Y_T, ..., Y_2|Y_1, x_1, ..., x_T)$$
+_more italic_
+```emacs-lisp
+(msg \"ok\")
+```
+$P_\\theta$
+_more italic_")))
+    (should (string-equal result "/some italic/
+$$P_\\theta(Y_T, ..., Y_2|Y_1, x_1, ..., x_T)$$
+/more italic/
+#+BEGIN_SRC emacs-lisp
+(msg \"ok\")
+#+END_SRC
+$P_\\theta$
+/more italic/"))))
+
+(ert-deftest test-ellama-replace-outside-of-code-blocks-minimal ()
+  (let ((result (ellama--replace-outside-of-code-blocks "This")))
+    (should (string-equal result "This"))))
+
+(ert-deftest test-ellama-md-to-org-code-snake-case ()
+  (let ((result (ellama--translate-markdown-to-org-filter "```python
+# Example of snake case variables and functions
+
+# Variable names using snake_case
+student_name = \"Alice Johnson\"
+class_name = \"Mathematics\"
+grade_level = 10
+
+# Function name using snake_case
+def calculate_average_score(math_score, science_score, english_score):
+    average_score = (math_score + science_score + english_score) / 3
+    return average_score
+
+# Using the function
+student_math_score = 85
+student_science_score = 90
+student_english_score = 78
+
+average_score = calculate_average_score(student_math_score, student_science_score, student_english_score)
+print(f\"The average score of {student_name} in {class_name} is: {average_score:.2f}\")
+```
+
+In this example:
+- Variable names like `student_name`, `class_name`, and `grade_level` use snake_case.
+- The function name `calculate_average_score` also follows the snake_case convention.
+
+Snake case helps improve readability, especially in languages that are sensitive to capitalization like Python.")))
+    (should (string-equal result "#+BEGIN_SRC python
+# Example of snake case variables and functions
+
+# Variable names using snake_case
+student_name = \"Alice Johnson\"
+class_name = \"Mathematics\"
+grade_level = 10
+
+# Function name using snake_case
+def calculate_average_score(math_score, science_score, english_score):
+    average_score = (math_score + science_score + english_score) / 3
+    return average_score
+
+# Using the function
+student_math_score = 85
+student_science_score = 90
+student_english_score = 78
+
+average_score = calculate_average_score(student_math_score, student_science_score, student_english_score)
+print(f\"The average score of {student_name} in {class_name} is: {average_score:.2f}\")
+#+END_SRC\n\nIn this example:\n- Variable names like ~student/name~, ~class/name~, and ~grade/level~ use snake/case.\n- The function name ~calculate/average/score~ also follows the snake_case convention.\n\nSnake case helps improve readability, especially in languages that are sensitive to capitalization\nlike Python."))))
+
+(ert-deftest test-ellama--fix-file-name ()
+  (should (string=
+	   (ellama--fix-file-name "a/\\?%*:|\"<>.;=")
+	   "a_____________")))
+
 (provide 'test-ellama)
 
 ;;; test-ellama.el ends here
